documentationtools.ReSTHeading
==============================

.. abjad-lineage:: abjad.tools.documentationtools.ReSTHeading.ReSTHeading.ReSTHeading

.. autoclass:: abjad.tools.documentationtools.ReSTHeading.ReSTHeading.ReSTHeading
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.documentationtools.ReSTHeading.ReSTHeading.ReSTHeading.depth
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTHeading.ReSTHeading.ReSTHeading.depthwise_inventory
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTHeading.ReSTHeading.ReSTHeading.graph_order
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTHeading.ReSTHeading.ReSTHeading.heading_characters
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTHeading.ReSTHeading.ReSTHeading.improper_parentage
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTHeading.ReSTHeading.ReSTHeading.parent
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTHeading.ReSTHeading.ReSTHeading.proper_parentage
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTHeading.ReSTHeading.ReSTHeading.rest_format
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTHeading.ReSTHeading.ReSTHeading.root
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTHeading.ReSTHeading.ReSTHeading.storage_format
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.documentationtools.ReSTHeading.ReSTHeading.ReSTHeading.level
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTHeading.ReSTHeading.ReSTHeading.name
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTHeading.ReSTHeading.ReSTHeading.text
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.documentationtools.ReSTHeading.ReSTHeading.ReSTHeading.__eq__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTHeading.ReSTHeading.ReSTHeading.__ge__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTHeading.ReSTHeading.ReSTHeading.__getstate__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTHeading.ReSTHeading.ReSTHeading.__gt__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTHeading.ReSTHeading.ReSTHeading.__le__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTHeading.ReSTHeading.ReSTHeading.__lt__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTHeading.ReSTHeading.ReSTHeading.__ne__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTHeading.ReSTHeading.ReSTHeading.__repr__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTHeading.ReSTHeading.ReSTHeading.__setstate__
   :noindex:
